@@ -3,7 +3,7 @@ A Canvas owns a set of Items and acts as a container for both the items
 and a constraint solver.
 """
 
-__version__ = "$Revision: 1972 $"
+__version__ = "$Revision: 2221 $"
 # $HeadURL: https://svn.devjavu.com/gaphor/gaphas/trunk/gaphas/canvas.py $
 
 import cairo
@@ -69,14 +69,13 @@ class Canvas(object):
         True
         """
         assert item not in self._tree.nodes, 'Adding already added node %s' % item
-        item.canvas = self
         self._tree.add(item, parent)
+        item._set_canvas(self)
         item._sort_key = self.sorter.get_key(item)
 
         self.update_matrix(item, parent)
 
         self.request_update(item)
-        #self._update_views((item,))
 
 
     @observed
@@ -85,9 +84,9 @@ class Canvas(object):
         Remove is done in a separate, @observed, method so the undo system
         can restore removed items in the right order.
         """
-        item.canvas = None
-        self._tree.remove(item)
         self.remove_connections_to_item(item)
+        item._set_canvas(None)
+        self._tree.remove(item)
         self._update_views(removed_items=(item,))
         self._dirty_items.discard(item)
         self._dirty_matrix_items.discard(item)
@@ -119,12 +118,8 @@ class Canvas(object):
         for a specific item.
         This is some brute force cleanup (e.g. if constraints are referenced
         by items, those references are not cleaned up).
-
-        This method implies the constraint used to keep the handle in place
-        is connected to Handle.connect_constraint.
         """
         for i, h in self.get_connected_items(item):
-            #self._solver.remove_constraint(h.connect_constraint)
             h.disconnect()
             # Never mind..
             h.connected_to = None
@@ -663,7 +658,6 @@ class CanvasProjection(object):
     >>> p._point
     (Variable(33, 40), Variable(10, 40))
 
-    TODO: How will this work on rotated variables?
     When the variables are retrieved, new values are calculated.
     """
 
@@ -688,8 +682,8 @@ class CanvasProjection(object):
         Return two delegating variables. Each variable should contain
         a value attribute with the real value.
         """
-        x, y = self._point
         item = self._item
+        x, y = self._point
         self._px, self._py = item.canvas.get_matrix_i2c(item).transform_point(x, y)
         return self._px, self._py
 
