@@ -3,7 +3,7 @@ Simple example items.
 These items are used in various tests.
 """
 
-__version__ = "$Revision: 1771 $"
+__version__ = "$Revision: 2213 $"
 # $HeadURL: https://svn.devjavu.com/gaphor/gaphas/trunk/gaphas/examples.py $
 
 from item import Handle, Element, Item
@@ -190,8 +190,9 @@ class ConnectingHandleTool(tool.HandleTool):
         Connect a handle to another item.
 
         In this "method" the following assumptios are made:
-         1. The only item that accepts handle connections are the Box instances
-         2. The only items with connectable handles are Line's
+        
+        1. The only item that accepts handle connections are the Box instances
+        2. The only items with connectable handles are Line's
          
         """
         def side(handle, glued):
@@ -213,13 +214,13 @@ class ConnectingHandleTool(tool.HandleTool):
 
         def handle_disconnect():
             try:
-                view.canvas.solver.remove_constraint(handle._connect_constraint)
+                view.canvas.solver.remove_constraint(handle.connection_data)
             except KeyError:
                 print 'constraint was already removed for', item, handle
                 pass # constraint was alreasy removed
             else:
                 print 'constraint removed for', item, handle
-            handle._connect_constraint = None
+            handle.connection_data = None
             handle.connected_to = None
             # Remove disconnect handler:
             handle.disconnect = lambda: 0
@@ -228,15 +229,15 @@ class ConnectingHandleTool(tool.HandleTool):
         glue_item = self.glue(view, item, handle, wx, wy)
         if glue_item and glue_item is handle.connected_to:
             try:
-                view.canvas.solver.remove_constraint(handle._connect_constraint)
+                view.canvas.solver.remove_constraint(handle.connection_data)
             except KeyError:
                 pass # constraint was already removed
 
             h1, h2 = side(handle, glue_item)
-            handle._connect_constraint = LineConstraint(line=(CanvasProjection(h1.pos, glue_item),
+            handle.connection_data = LineConstraint(line=(CanvasProjection(h1.pos, glue_item),
                                       CanvasProjection(h2.pos, glue_item)),
                                 point=CanvasProjection(handle.pos, item))
-            view.canvas.solver.add_constraint(handle._connect_constraint)
+            view.canvas.solver.add_constraint(handle.connection_data)
 
             handle.disconnect = handle_disconnect
             return
@@ -250,11 +251,11 @@ class ConnectingHandleTool(tool.HandleTool):
                 h1, h2 = side(handle, glue_item)
 
                 # Make a constraint that keeps into account item coordinates.
-                handle._connect_constraint = \
+                handle.connection_data = \
                         LineConstraint(line=(CanvasProjection(h1.pos, glue_item),
                             CanvasProjection(h2.pos, glue_item)),
                             point=CanvasProjection(handle.pos, item))
-                view.canvas.solver.add_constraint(handle._connect_constraint)
+                view.canvas.solver.add_constraint(handle.connection_data)
 
                 handle.connected_to = glue_item
                 handle.disconnect = handle_disconnect
@@ -262,7 +263,7 @@ class ConnectingHandleTool(tool.HandleTool):
     def disconnect(self, view, item, handle):
         if handle.connected_to:
             #print 'Handle.disconnect', view, item, handle
-            view.canvas.solver.remove_constraint(handle._connect_constraint)
+            view.canvas.solver.remove_constraint(handle.connection_data)
 
 
 def DefaultExampleTool():
