@@ -8,8 +8,8 @@ A point is represented as a tuple (x, y).
 
 """
 
-__version__ = "$Revision: 1578 $"
-# $HeadURL: https://svn.devjavu.com/gaphor/gaphas/tags/gaphas-0.2.0/gaphas/geometry.py $
+__version__ = "$Revision: 1794 $"
+# $HeadURL: https://svn.devjavu.com/gaphor/gaphas/trunk/gaphas/geometry.py $
 
 from math import sqrt
 
@@ -134,7 +134,7 @@ class Rectangle(object):
         >>> r + (0, 0)
         Traceback (most recent call last):
           ...
-        AttributeError: Can only add Rectangle or tuple (x, y, width, height), not (0, 0).
+        TypeError: Can only add Rectangle or tuple (x, y, width, height), not (0, 0).
         >>> r + (20, 30, 40, 50)
         Rectangle(5, 7, 55, 73)
         """
@@ -150,12 +150,12 @@ class Rectangle(object):
         >>> r += 'aap'
         Traceback (most recent call last):
           ...
-        AttributeError: Can only add Rectangle or tuple (x, y, width, height), not 'aap'.
+        TypeError: Can only add Rectangle or tuple (x, y, width, height), not 'aap'.
         """
         try:
             x, y, width, height = obj
         except ValueError:
-            raise AttributeError, "Can only add Rectangle or tuple (x, y, width, height), not %s." % repr(obj)
+            raise TypeError, "Can only add Rectangle or tuple (x, y, width, height), not %s." % repr(obj)
         x1, y1 = x + width, y + height
         if self:
             ox1, oy1 = self.x + self.width, self.y + self.height
@@ -183,19 +183,19 @@ class Rectangle(object):
     def __isub__(self, obj):
         """
         >>> r = Rectangle()
-        >>> r -= Rectangle(5,7,20,25)
+        >>> r -= Rectangle(5, 7, 20, 25)
         >>> r -= (0, 0, 30, 10)
         >>> r
         Rectangle(5, 7, 20, 3)
         >>> r -= 'aap'
         Traceback (most recent call last):
           ...
-        AttributeError: Can only substract Rectangle or tuple (x, y, width, height), not 'aap'.
+        TypeError: Can only substract Rectangle or tuple (x, y, width, height), not 'aap'.
         """
         try:
             x, y, width, height = obj
         except ValueError:
-            raise AttributeError, "Can only substract Rectangle or tuple (x, y, width, height), not %s." % repr(obj)
+            raise TypeError, "Can only substract Rectangle or tuple (x, y, width, height), not %s." % repr(obj)
         x1, y1 = x + width, y + height
 
         if self:
@@ -210,7 +210,8 @@ class Rectangle(object):
         return self
 
     def __contains__(self, obj):
-        """ Check if a point (x, y) in inside rectangle (x, y, width, height)
+        """
+        Check if a point (x, y) in inside rectangle (x, y, width, height)
         or if a rectangle instance is inside with the rectangle.
 
         >>> r=Rectangle(10, 5, 12, 12)
@@ -233,7 +234,7 @@ class Rectangle(object):
         >>> 'aap' in r
         Traceback (most recent call last):
           ...
-        AttributeError: Should compare to Rectangle, tuple (x, y, width, height) or point (x, y), not 'aap'.
+        TypeError: Should compare to Rectangle, tuple (x, y, width, height) or point (x, y), not 'aap'.
         """
         try:
             x, y, width, height = obj
@@ -244,7 +245,7 @@ class Rectangle(object):
                 x, y = obj
                 x1, y1 = obj
             except ValueError:
-                raise AttributeError, "Should compare to Rectangle, tuple (x, y, width, height) or point (x, y), not %s." % repr(obj)
+                raise TypeError, "Should compare to Rectangle, tuple (x, y, width, height) or point (x, y), not %s." % repr(obj)
         return x >= self.x and x1 <= self.x1 and \
                y >= self.y and y1 <= self.y1
 
@@ -448,6 +449,48 @@ def intersect_line_line(line1_start, line1_end, line2_start, line2_end):
         return xi, yi
 
 
+def rectangle_contains(inner, outer):
+    """
+    Returns True if inner rect is contained in outer rect.
+    """
+    ix, iy, iw, ih = inner
+    ox, oy, ow, oh = outer
+    return ox <= ix and oy <= iy and ox + ow >= ix + iw and oy + oh >= iy + ih
+
+
+def rectangle_intersects(recta, rectb):
+    """
+    Return True if recta and rectb intersect.
+
+    >>> rectangle_intersects((5,5,20, 20), (10, 10, 1, 1))
+    True
+    >>> rectangle_intersects((40, 30, 10, 1), (1, 1, 1, 1))
+    False
+    """
+    ax, ay, aw, ah = recta
+    bx, by, bw, bh = rectb
+    return ax <= bx + bw and ax + aw >= bx and ay <= by + bh and ay + ah >= by
+
+
+def rectangle_clip(recta, rectb):
+    """
+    Return the clipped rectangle of ``recta`` and ``rectb``. If they do not
+    intersect, ``None`` is returned.
+
+    >>> rectangle_clip((0, 0, 20, 20), (10, 10, 20, 20))
+    (10, 10, 10, 10)
+    """
+    ax, ay, aw, ah = recta
+    bx, by, bw, bh = rectb
+    x = max(ax, bx)
+    y = max(ay, by)
+    w = min(ax +aw, bx + bw) - x
+    h = min(ay +ah, by + bh) - y
+    if w < 0 or h < 0:
+        return None
+    return (x, y, w, h)
+
+
 if __name__ == '__main__':
     import doctest
     doctest.testmod()
