@@ -2,7 +2,7 @@
 Basic items.
 """
 
-__version__ = "$Revision: 1917 $"
+__version__ = "$Revision: 2214 $"
 # $HeadURL: https://svn.devjavu.com/gaphor/gaphas/trunk/gaphas/item.py $
 
 from math import atan2
@@ -39,7 +39,10 @@ class Handle(object):
         self._visible = True
         self._connected_to = None
 
-        # The constraint used to keep the handle visually connected
+        # User data for the connection (e.g. constraints)
+        self._connection_data = None
+        # An extra property used to disconnect the constraint. Should be set
+        # by the application.
         self._disconnect = lambda: 0
 
     @observed
@@ -78,7 +81,15 @@ class Handle(object):
     def _set_connected_to(self, connected_to):
         self._connected_to = connected_to
 
-    connected_to = reversible_property(lambda s: s._connected_to, _set_connected_to)
+    connected_to = reversible_property(lambda s: s._connected_to,
+                                       _set_connected_to)
+
+    @observed
+    def _set_connection_data(self, connection_data):
+        self._connection_data = connection_data
+
+    connection_data = reversible_property(lambda s: s._connection_data,
+                                          _set_connection_data)
 
     @observed
     def _set_disconnect(self, disconnect):
@@ -151,10 +162,13 @@ class Item(object):
         self._sort_key = None
 
 
-    @observed
+    # _set_canvas() is not observed, since this operation is initialized by
+    # Canvas.add() and Canvas.remove()
+    #@observed
     def _set_canvas(self, canvas):
         """
-        Set the canvas.
+        Set the canvas. Should only be called from Canvas.add and
+        Canvas.remove().
         """
         assert not canvas or not self._canvas or self._canvas is canvas
         if self._canvas:
@@ -163,15 +177,8 @@ class Item(object):
         if canvas:
             self.setup_canvas()
 
-    def _del_canvas(self):
-        """
-        Unset the canvas.
-        """
-        self._set_canvas(None)
-
-    canvas = reversible_property(lambda s: s._canvas, _set_canvas, _del_canvas,
-                doc="Set canvas for the item. Application should use " + \
-                    "Canvas.add() and Canvas.remove().")
+    canvas = reversible_property(lambda s: s._canvas,
+                doc="Canvas owning this item")
 
 
     def setup_canvas(self):
@@ -208,6 +215,7 @@ class Item(object):
 
     matrix = reversible_property(lambda s: s._matrix, _set_matrix)
 
+
     def request_update(self, update=True, matrix=True):
         if self._canvas:
             self._canvas.request_update(self, update=update, matrix=matrix)
