@@ -3,11 +3,14 @@ Some Gaphor specific updates to the canvas. This is done by setting the
 correct properties on gaphas' modules.
 
 Matrix
---------------
-Small utility class wrapping cairo.Matrix. The UndoableMatrix class
+------
+Small utility class wrapping cairo.Matrix. The `Matrix` class
 adds state preservation capabilities.
 """
 
+__version__ = "$Revision: 1839 $"
+# $HeadURL: https://svn.devjavu.com/gaphor/gaphas/trunk/gaphas/matrix.py $
+
 import cairo
 from state import observed, reversible_method
 
