@@ -21,7 +21,7 @@ Maybe even:
     (context.view = view; context.grab() to grab, context.ungrab() to ungrab)
 """
 
-__version__ = "$Revision: 1916 $"
+__version__ = "$Revision: 2173 $"
 # $HeadURL: https://svn.devjavu.com/gaphor/gaphas/trunk/gaphas/tool.py $
 
 import cairo
@@ -189,10 +189,43 @@ class ToolChain(Tool):
         self._grabbed_tool = None
 
     def append(self, tool):
+        """
+        Append a tool to the chain. Self is returned.
+        """
         self._tools.append(tool)
+        return self
 
     def prepend(self, tool):
+        """
+        Prepend a tool to the chain. Self is returned.
+        """
         self._tools.insert(0, tool)
+        return self
+
+    def swap(self, old_tool_class, new_tool):
+        """
+        Swap one tool for another. Note that the first argument is the tool's
+        class (type), not an instance.
+
+        >>> chain = ToolChain().append(HoverTool()).append(RubberbandTool())
+        >>> chain._tools # doctest: +ELLIPSIS
+        [<gaphas.tool.HoverTool object at 0x...>, <gaphas.tool.RubberbandTool object at 0x...>]
+        >>> chain.swap(HoverTool, ItemTool()) # doctest: +ELLIPSIS
+        <gaphas.tool.ToolChain object at 0x...>
+
+        Now the HoverTool has been substituted for the ItemTool:
+        
+        >>> chain._tools # doctest: +ELLIPSIS
+        [<gaphas.tool.ItemTool object at 0x...>, <gaphas.tool.RubberbandTool object at 0x...>]
+        """
+        tools = self._tools
+        for i in xrange(len(tools)):
+            if type(tools[i]) is old_tool_class:
+                if self._grabbed_tool is tools[i]:
+                    raise ValueError, 'Can\'t swap tools since %s is grabbed' % tools[i]
+                tools[i] = new_tool
+                break
+        return self
 
     def grab(self, tool):
         if not self._grabbed_tool:
@@ -288,7 +321,7 @@ class ItemTool(Tool):
             del view.selected_items
         if view.hovered_item:
             if view.hovered_item in view.selected_items and \
-               event.state & gtk.gdk.CONTROL_MASK:
+                    event.state & gtk.gdk.CONTROL_MASK:
                 view.focused_item = None
                 view.unselect_item(view.hovered_item)
             else:
@@ -332,6 +365,11 @@ class ItemTool(Tool):
                 i.matrix.translate(*v2i.transform_distance(dx, dy))
                 canvas.request_matrix_update(i)
 
+            # TODO: if isinstance(item, Element):
+            #   schedule item to be handled by some "guides" tool
+            #   that tries to align the handle with some other Element's
+            #   handle.
+
             self.last_x, self.last_y = event.x, event.y
             return True
 
@@ -356,6 +394,12 @@ class HandleTool(Tool):
         self._grabbed_item = item
         self._grabbed_handle = handle
 
+    def ungrab_handle(self):
+        """
+        Reset _grabbed_handle and _grabbed_item.
+        """
+        self._grabbed_handle = None
+        self._grabbed_item = None
 
     def _find_handle(self, view, event, item):
         """
@@ -457,14 +501,17 @@ class HandleTool(Tool):
         Release a grabbed handle.
         """
         # queue extra redraw to make sure the item is drawn properly
+        grabbed_handle, grabbed_item = self._grabbed_handle, self._grabbed_item
         try:
             view = context.view
-            if self._grabbed_handle and self._grabbed_handle.connectable:
-                self.connect(view, self._grabbed_item, self._grabbed_handle, event.x, event.y)
+            if grabbed_handle and grabbed_handle.connectable:
+                self.connect(view, grabbed_item, grabbed_handle, event.x, event.y)
         finally:
             context.ungrab()
-        if self._grabbed_handle:
-            self._grabbed_item.request_update()
+            self.ungrab_handle()
+
+        if grabbed_handle:
+            grabbed_item.request_update()
         return True
 
     def on_motion_notify(self, context, event):
@@ -491,6 +538,10 @@ class HandleTool(Tool):
             try:
                 if self._grabbed_handle.connectable:
                     self.glue(view, item, handle, event.x, event.y)
+                # TODO: elif isinstance(item, Element):
+                #   schedule (item, handle) to be handled by some "guides" tool
+                #   that tries to align the handle with some other Element's
+                #   handle.
             finally:
                 pass
             return True
@@ -642,12 +693,12 @@ def DefaultTool():
     """
     The default tool chain build from HoverTool, ItemTool and HandleTool.
     """
-    chain = ToolChain()
-    chain.append(HoverTool())
-    chain.append(HandleTool())
-    chain.append(ItemTool())
-    chain.append(TextEditTool())
-    chain.append(RubberbandTool())
+    chain = ToolChain().\
+        append(HoverTool()).\
+        append(HandleTool()).\
+        append(ItemTool()).\
+        append(TextEditTool()).\
+        append(RubberbandTool())
     return chain
 
 
